@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,17 +29,17 @@ import (
 	"strings"
 	"time"
 
-	"go.cypherpunks.ru/recfile"
-	"go.cypherpunks.ru/tai64n/v2"
+	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/tai64n/v4"
 )
 
 const HumanTimeFmt = "2006-01-02 15:04:05.000000000 Z07:00"
 
 type BuildLogJob struct {
 	tgt      *Tgt
+	rec      map[string][]string
 	started  time.Time
 	exitCode int
-	rec      map[string][]string
 }
 
 type ByStarted []*BuildLogJob
@@ -200,7 +200,8 @@ func showBuildLog(tgt *Tgt, buildLogRec map[string][]string, depth int) error {
 		if dep.rel == tgt.rel {
 			continue
 		}
-		rec, err := parseBuildLogRec(dep)
+		var rec map[string][]string
+		rec, err = parseBuildLogRec(dep)
 		if err != nil {
 			if errors.Is(err, fs.ErrNotExist) {
 				continue
@@ -210,7 +211,8 @@ func showBuildLog(tgt *Tgt, buildLogRec map[string][]string, depth int) error {
 		if rec["Build"][0] != buildLogRec["Build"][0] {
 			continue
 		}
-		started, err := tai64n.Decode(rec["Started"][0])
+		var started time.Time
+		started, err = tai64n.Decode(rec["Started"][0])
 		if err != nil {
 			return ErrLine(err)
 		}
