@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ import (
 	"syscall"
 
 	"github.com/google/uuid"
-	"go.cypherpunks.ru/recfile"
+	"go.cypherpunks.su/recfile/v2"
 	"golang.org/x/sys/unix"
 )
 
@@ -255,7 +255,8 @@ func main() {
 		if _, err = fd.Seek(0, io.SeekStart); err != nil {
 			log.Fatal(err)
 		}
-		tgtsRaw, err := io.ReadAll(bufio.NewReader(fd))
+		var tgtsRaw []byte
+		tgtsRaw, err = io.ReadAll(bufio.NewReader(fd))
 		if err != nil {
 			log.Fatal(err)
 		}
