@@ -227,7 +227,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			tracef(CLock, "LOCK_EX: %s", fdLock.Name())
 		LockAgain:
 			if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
-				if errors.Is(err, unix.EDEADLK) {
+				if errors.Is(err, unix.EDEADLK) || errors.Is(err, unix.EINTR) {
 					time.Sleep(10 * time.Millisecond)
 					goto LockAgain
 				}
